summaryrefslogtreecommitdiff
path: root/innobase/include
diff options
context:
space:
mode:
authorunknown <marko@hundin.mysql.fi>2004-04-07 14:19:26 +0300
committerunknown <marko@hundin.mysql.fi>2004-04-07 14:19:26 +0300
commit095d64633b94e5e840503a26dd9ec2c0a66dfd5f (patch)
tree2f1cb9f7307ff2cede7e13d739760692e11dcaaf /innobase/include
parent1f50a0345c78ff969ddabf52322d3feeb163ec67 (diff)
downloadmariadb-git-095d64633b94e5e840503a26dd9ec2c0a66dfd5f.tar.gz
InnoDB: Remove debug functions unless #ifdef UNIV_DEBUG
innobase/btr/btr0btr.c: Add #ifdef UNIV_DEBUG around debug code innobase/buf/buf0buf.c: Add #ifdef UNIV_DEBUG around debug code innobase/buf/buf0flu.c: Add #ifdef UNIV_DEBUG around debug code innobase/buf/buf0lru.c: Add #ifdef UNIV_DEBUG around debug code innobase/buf/buf0rea.c: Add #ifdef UNIV_DEBUG around debug code innobase/data/data0type.c: Add #ifdef UNIV_DEBUG around debug code innobase/dict/dict0dict.c: Add #ifdef UNIV_DEBUG around debug code innobase/fsp/fsp0fsp.c: Add #ifdef UNIV_DEBUG around debug code innobase/fut/fut0lst.c: Add #ifdef UNIV_DEBUG around debug code innobase/ibuf/ibuf0ibuf.c: Add #ifdef UNIV_DEBUG around debug code innobase/include/btr0btr.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/buf0buf.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/buf0buf.ic: Remove global declaration of buf_dbg_counter innobase/include/buf0flu.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/buf0lru.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/data0type.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/dict0dict.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/fsp0fsp.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/fut0lst.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/lock0lock.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/mem0dbg.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/mem0dbg.ic: Add #ifdef UNIV_MEM_DEBUG around debug code innobase/include/mem0pool.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/mtr0mtr.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/pars0opt.h: Add #ifdef UNIV_SQL_DEBUG around debug code innobase/include/sync0rw.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/sync0sync.h: Add #ifdef UNIV_DEBUG around debug code innobase/include/trx0sys.h: Add #ifdef UNIV_HOTBACKUP around InnoDB Hot Backup specific code innobase/lock/lock0lock.c: Add #ifdef UNIV_DEBUG around debug code innobase/mem/mem0dbg.c: Add #ifdef UNIV_DEBUG around debug code innobase/mem/mem0pool.c: Add #ifdef UNIV_DEBUG around debug code innobase/mtr/mtr0mtr.c: Add #ifdef UNIV_DEBUG around debug code innobase/pars/pars0opt.c: Add #ifdef UNIV_SQL_DEBUG around debug code innobase/srv/srv0start.c: Add #ifdef UNIV_DEBUG around debug code innobase/sync/sync0rw.c: Add #ifdef UNIV_DEBUG around debug code innobase/sync/sync0sync.c: Add #ifdef UNIV_DEBUG around debug code innobase/trx/trx0roll.c: Add #ifdef UNIV_DEBUG around debug code innobase/trx/trx0sys.c: Add #ifdef UNIV_HOTBACKUP around InnoDB Hot Backup specific code
Diffstat (limited to 'innobase/include')
-rw-r--r--innobase/include/btr0btr.h2
-rw-r--r--innobase/include/buf0buf.h10
-rw-r--r--innobase/include/buf0buf.ic4
-rw-r--r--innobase/include/buf0flu.h2
-rw-r--r--innobase/include/buf0lru.h2
-rw-r--r--innobase/include/data0type.h2
-rw-r--r--innobase/include/dict0dict.h14
-rw-r--r--innobase/include/fsp0fsp.h2
-rw-r--r--innobase/include/fut0lst.h3
-rw-r--r--innobase/include/lock0lock.h6
-rw-r--r--innobase/include/mem0dbg.h4
-rw-r--r--innobase/include/mem0dbg.ic3
-rw-r--r--innobase/include/mem0pool.h3
-rw-r--r--innobase/include/mtr0mtr.h2
-rw-r--r--innobase/include/pars0opt.h2
-rw-r--r--innobase/include/sync0rw.h2
-rw-r--r--innobase/include/sync0sync.h2
-rw-r--r--innobase/include/trx0sys.h2
18 files changed, 51 insertions, 16 deletions
diff --git a/innobase/include/btr0btr.h b/innobase/include/btr0btr.h
index 8606fcd2a5c..e904db3272f 100644
--- a/innobase/include/btr0btr.h
+++ b/innobase/include/btr0btr.h
@@ -392,6 +392,7 @@ btr_page_free_low(
page_t* page, /* in: page to be freed, x-latched */
ulint level, /* in: page level */
mtr_t* mtr); /* in: mtr */
+#ifdef UNIV_DEBUG
/*****************************************************************
Prints size info of a B-tree. */
@@ -408,6 +409,7 @@ btr_print_tree(
dict_tree_t* tree, /* in: tree */
ulint width); /* in: print this many entries from start
and end */
+#endif /* UNIV_DEBUG */
/****************************************************************
Checks the size and number of fields in a record based on the definition of
the index. */
diff --git a/innobase/include/buf0buf.ic b/innobase/include/buf0buf.ic
index 16deade0901..7e2a9b59378 100644
--- a/innobase/include/buf0buf.ic
+++ b/innobase/include/buf0buf.ic
@@ -11,10 +11,6 @@ Created 11/5/1995 Heikki Tuuri
#include "buf0rea.h"
#include "mtr0mtr.h"
-extern ulint buf_dbg_counter; /* This is used to insert validation
- operations in execution in the
- debug version */
-
/************************************************************************
Recommends a move of a block to the start of the LRU list if there is danger
of dropping from the buffer pool. NOTE: does not reserve the buffer pool
diff --git a/innobase/include/buf0flu.h b/innobase/include/buf0flu.h
index 1b40acaa269..6f39eef7210 100644
--- a/innobase/include/buf0flu.h
+++ b/innobase/include/buf0flu.h
@@ -97,6 +97,7 @@ buf_flush_ready_for_replace(
/* out: TRUE if can replace immediately */
buf_block_t* block); /* in: buffer control block, must be in state
BUF_BLOCK_FILE_PAGE and in the LRU list */
+#ifdef UNIV_DEBUG
/**********************************************************************
Validates the flush list. */
@@ -104,6 +105,7 @@ ibool
buf_flush_validate(void);
/*====================*/
/* out: TRUE if ok */
+#endif /* UNIV_DEBUG */
/* When buf_flush_free_margin is called, it tries to make this many blocks
available to replacement in the free list and at the end of the LRU list (to
diff --git a/innobase/include/buf0lru.h b/innobase/include/buf0lru.h
index eb9d43d3b93..a9d57ecb36e 100644
--- a/innobase/include/buf0lru.h
+++ b/innobase/include/buf0lru.h
@@ -100,6 +100,7 @@ void
buf_LRU_make_block_old(
/*===================*/
buf_block_t* block); /* in: control block */
+#ifdef UNIV_DEBUG
/**************************************************************************
Validates the LRU list. */
@@ -112,6 +113,7 @@ Prints the LRU list. */
void
buf_LRU_print(void);
/*===============*/
+#endif /* UNIV_DEBUG */
#ifndef UNIV_NONINL
#include "buf0lru.ic"
diff --git a/innobase/include/data0type.h b/innobase/include/data0type.h
index 4da686bf2e1..d10d20cf69e 100644
--- a/innobase/include/data0type.h
+++ b/innobase/include/data0type.h
@@ -190,6 +190,7 @@ dtype_read_for_order_and_null_size(
/*===============================*/
dtype_t* type, /* in: type struct */
byte* buf); /* in: buffer for the stored order info */
+#ifdef UNIV_DEBUG
/*************************************************************************
Validates a data type structure. */
@@ -198,6 +199,7 @@ dtype_validate(
/*===========*/
/* out: TRUE if ok */
dtype_t* type); /* in: type struct to validate */
+#endif /* UNIV_DEBUG */
/*************************************************************************
Prints a data type structure. */
diff --git a/innobase/include/dict0dict.h b/innobase/include/dict0dict.h
index 835c2c2b2e6..fadbcf37a43 100644
--- a/innobase/include/dict0dict.h
+++ b/innobase/include/dict0dict.h
@@ -301,18 +301,19 @@ dict_table_get_index_noninline(
dict_table_t* table, /* in: table */
char* name); /* in: index name */
/**************************************************************************
-Prints a table definition. */
+Prints a table data. */
void
-dict_table_print(
-/*=============*/
+dict_table_print_low(
+/*=================*/
dict_table_t* table); /* in: table */
+#ifdef UNIV_DEBUG
/**************************************************************************
-Prints a table data. */
+Prints a table definition. */
void
-dict_table_print_low(
-/*=================*/
+dict_table_print(
+/*=============*/
dict_table_t* table); /* in: table */
/**************************************************************************
Prints a table data when we know the table name. */
@@ -321,6 +322,7 @@ void
dict_table_print_by_name(
/*=====================*/
char* name);
+#endif /* UNIV_DEBUG */
/**************************************************************************
Outputs info on foreign keys of a table. */
diff --git a/innobase/include/fsp0fsp.h b/innobase/include/fsp0fsp.h
index 3494f336b1e..82c144bc766 100644
--- a/innobase/include/fsp0fsp.h
+++ b/innobase/include/fsp0fsp.h
@@ -297,6 +297,7 @@ void
fsp_print(
/*======*/
ulint space); /* in: space id */
+#ifdef UNIV_DEBUG
/***********************************************************************
Validates a segment. */
@@ -314,6 +315,7 @@ fseg_print(
/*=======*/
fseg_header_t* header, /* in: segment header */
mtr_t* mtr); /* in: mtr */
+#endif /* UNIV_DEBUG */
/* Flags for fsp_reserve_free_extents */
#define FSP_NORMAL 1000000
diff --git a/innobase/include/fut0lst.h b/innobase/include/fut0lst.h
index 5427e2248da..3f679d61ab5 100644
--- a/innobase/include/fut0lst.h
+++ b/innobase/include/fut0lst.h
@@ -181,6 +181,7 @@ flst_validate(
/* out: TRUE if ok */
flst_base_node_t* base, /* in: pointer to base node of list */
mtr_t* mtr1); /* in: mtr */
+#ifdef UNIV_DEBUG
/************************************************************************
Prints info of a file-based list. */
@@ -189,7 +190,7 @@ flst_print(
/*=======*/
flst_base_node_t* base, /* in: pointer to base node of list */
mtr_t* mtr); /* in: mtr */
-
+#endif /* UNIV_DEBUG */
#ifndef UNIV_NONINL
#include "fut0lst.ic"
diff --git a/innobase/include/lock0lock.h b/innobase/include/lock0lock.h
index 94ef3b33ebc..9ccea5ad7a4 100644
--- a/innobase/include/lock0lock.h
+++ b/innobase/include/lock0lock.h
@@ -19,7 +19,9 @@ Created 5/7/1996 Heikki Tuuri
#include "read0types.h"
#include "hash0hash.h"
+#ifdef UNIV_DEBUG
extern ibool lock_print_waits;
+#endif /* UNIV_DEBUG */
/* Buffer for storing information about the most recent deadlock error */
extern FILE* lock_latest_err_file;
@@ -455,6 +457,7 @@ lock_check_trx_id_sanity(
dict_index_t* index, /* in: clustered index */
ibool has_kernel_mutex);/* in: TRUE if the caller owns the
kernel mutex */
+#ifdef UNIV_DEBUG
/*************************************************************************
Validates the lock queue on a single record. */
@@ -464,6 +467,7 @@ lock_rec_queue_validate(
/* out: TRUE if ok */
rec_t* rec, /* in: record to look at */
dict_index_t* index); /* in: index, or NULL if not known */
+#endif /* UNIV_DEBUG */
/*************************************************************************
Prints info of a table lock. */
@@ -487,6 +491,7 @@ void
lock_print_info(
/*============*/
FILE* file); /* in: file where to print */
+#ifdef UNIV_DEBUG
/*************************************************************************
Validates the lock queue on a table. */
@@ -511,6 +516,7 @@ ibool
lock_validate(void);
/*===============*/
/* out: TRUE if ok */
+#endif /* UNIV_DEBUG */
/* The lock system */
extern lock_sys_t* lock_sys;
diff --git a/innobase/include/mem0dbg.h b/innobase/include/mem0dbg.h
index 6c92d669be3..61c66cc218c 100644
--- a/innobase/include/mem0dbg.h
+++ b/innobase/include/mem0dbg.h
@@ -31,6 +31,7 @@ check fields at the both ends of the field. */
#define MEM_SPACE_NEEDED(N) ut_calc_align((N), UNIV_MEM_ALIGNMENT)
#endif
+#ifdef UNIV_DEBUG
/*******************************************************************
Checks a memory heap for consistency and prints the contents if requested.
Outputs the sum of sizes of buffers given to the user (only in
@@ -60,6 +61,7 @@ mem_heap_validate_or_print(
ulint* n_blocks); /* out: number of blocks in the heap,
if a NULL pointer is passed as this
argument, it is ignored */
+#endif /* UNIV_DEBUG */
#ifdef UNIV_MEM_DEBUG
/******************************************************************
Prints the contents of a memory heap. */
@@ -69,6 +71,7 @@ mem_heap_print(
/*===========*/
mem_heap_t* heap); /* in: memory heap */
#endif /* UNIV_MEM_DEBUG */
+#ifdef UNIV_DEBUG
/******************************************************************
Checks that an object is a memory heap (or a block of it) */
@@ -85,6 +88,7 @@ mem_heap_validate(
/*==============*/
/* out: TRUE if ok */
mem_heap_t* heap); /* in: memory heap */
+#endif /* UNIV_DEBUG */
#ifdef UNIV_MEM_DEBUG
/*********************************************************************
TRUE if no memory is currently allocated. */
diff --git a/innobase/include/mem0dbg.ic b/innobase/include/mem0dbg.ic
index 6efac719760..2e79c814529 100644
--- a/innobase/include/mem0dbg.ic
+++ b/innobase/include/mem0dbg.ic
@@ -56,6 +56,7 @@ mem_hash_insert(
mem_heap_t* heap, /* in: the created heap */
char* file_name, /* in: file name of creation */
ulint line); /* in: line where created */
+#ifdef UNIV_MEM_DEBUG
/*******************************************************************
Removes a memory heap (which is going to be freed by the caller)
from the list of live memory heaps. Returns the size of the heap
@@ -71,7 +72,7 @@ mem_hash_remove(
mem_heap_t* heap, /* in: the heap to be freed */
char* file_name, /* in: file name of freeing */
ulint line); /* in: line where freed */
-
+#endif /* UNIV_MEM_DEBUG */
void
mem_field_header_set_len(byte* field, ulint len);
diff --git a/innobase/include/mem0pool.h b/innobase/include/mem0pool.h
index 43707bd5f61..95cf19676fb 100644
--- a/innobase/include/mem0pool.h
+++ b/innobase/include/mem0pool.h
@@ -83,6 +83,7 @@ Releases the mem pool mutex. */
void
mem_pool_mutex_exit(void);
/*=====================*/
+#ifdef UNIV_DEBUG
/************************************************************************
Validates a memory pool. */
@@ -99,7 +100,7 @@ mem_pool_print_info(
/*================*/
FILE* outfile,/* in: output file to write to */
mem_pool_t* pool); /* in: memory pool */
-
+#endif /* UNIV_DEBUG */
#ifndef UNIV_NONINL
#include "mem0pool.ic"
diff --git a/innobase/include/mtr0mtr.h b/innobase/include/mtr0mtr.h
index d999b7cc5b7..6117927504f 100644
--- a/innobase/include/mtr0mtr.h
+++ b/innobase/include/mtr0mtr.h
@@ -250,6 +250,7 @@ mtr_memo_contains(
mtr_t* mtr, /* in: mtr */
void* object, /* in: object to search */
ulint type); /* in: type of object */
+#ifdef UNIV_DEBUG
/*************************************************************
Prints info of an mtr handle. */
@@ -257,6 +258,7 @@ void
mtr_print(
/*======*/
mtr_t* mtr); /* in: mtr */
+#endif /* UNIV_DEBUG */
/*######################################################################*/
#define MTR_BUF_MEMO_SIZE 200 /* number of slots in memo */
diff --git a/innobase/include/pars0opt.h b/innobase/include/pars0opt.h
index d091c3ee2d0..ac0e885d05a 100644
--- a/innobase/include/pars0opt.h
+++ b/innobase/include/pars0opt.h
@@ -43,6 +43,7 @@ opt_find_all_cols(
to add new found columns */
plan_t* plan, /* in: plan or NULL */
que_node_t* exp); /* in: expression or condition */
+#ifdef UNIV_SQL_DEBUG
/************************************************************************
Prints info of a query plan. */
@@ -50,6 +51,7 @@ void
opt_print_query_plan(
/*=================*/
sel_node_t* sel_node); /* in: select node */
+#endif /* UNIV_SQL_DEBUG */
#ifndef UNIV_NONINL
#include "pars0opt.ic"
diff --git a/innobase/include/sync0rw.h b/innobase/include/sync0rw.h
index d71691b4353..82123a529a3 100644
--- a/innobase/include/sync0rw.h
+++ b/innobase/include/sync0rw.h
@@ -85,6 +85,7 @@ void
rw_lock_free(
/*=========*/
rw_lock_t* lock); /* in: rw-lock */
+#ifdef UNIV_DEBUG
/**********************************************************************
Checks that the rw-lock has been initialized and that there are no
simultaneous shared and exclusive locks. */
@@ -93,6 +94,7 @@ ibool
rw_lock_validate(
/*=============*/
rw_lock_t* lock);
+#endif /* UNIV_DEBUG */
/******************************************************************
NOTE! The following macros should be used in rw s-locking, not the
corresponding function. */
diff --git a/innobase/include/sync0sync.h b/innobase/include/sync0sync.h
index 3348da2851c..abc5350b6c0 100644
--- a/innobase/include/sync0sync.h
+++ b/innobase/include/sync0sync.h
@@ -127,6 +127,7 @@ void
sync_print(
/*=======*/
FILE* file); /* in: file where to print */
+#ifdef UNIV_DEBUG
/**********************************************************************
Checks that the mutex has been initialized. */
@@ -134,6 +135,7 @@ ibool
mutex_validate(
/*===========*/
mutex_t* mutex);
+#endif /* UNIV_DEBUG */
/**********************************************************************
Sets the mutex latching level field. */
diff --git a/innobase/include/trx0sys.h b/innobase/include/trx0sys.h
index 755bcb28611..c7ef4d1929d 100644
--- a/innobase/include/trx0sys.h
+++ b/innobase/include/trx0sys.h
@@ -268,6 +268,7 @@ the magic number shows it valid. */
void
trx_sys_print_mysql_binlog_offset(void);
/*===================================*/
+#ifdef UNIV_HOTBACKUP
/*********************************************************************
Prints to stderr the MySQL binlog info in the system header if the
magic number shows it valid. */
@@ -277,6 +278,7 @@ trx_sys_print_mysql_binlog_offset_from_page(
/*========================================*/
byte* page); /* in: buffer containing the trx system header page,
i.e., page number TRX_SYS_PAGE_NO in the tablespace */
+#endif /* UNIV_HOTBACKUP */
/*********************************************************************
Prints to stderr the MySQL master log offset info in the trx system header if
the magic number shows it valid. */
diff --git a/innobase/include/buf0buf.h b/innobase/include/buf0buf.h
index 5ac9c83a5f9..11c9047a8fc 100644
--- a/innobase/include/buf0buf.h
+++ b/innobase/include/buf0buf.h
@@ -53,9 +53,11 @@ Created 11/5/1995 Heikki Tuuri
#define BUF_KEEP_OLD 52
extern buf_pool_t* buf_pool; /* The buffer pool of the database */
+#ifdef UNIV_DEBUG
extern ibool buf_debug_prints;/* If this is set TRUE, the program
prints info whenever read or flush
occurs */
+#endif /* UNIV_DEBUG */
/************************************************************************
Initializes the buffer pool of the database. */
@@ -452,12 +454,14 @@ buf_pool_is_block(
/*==============*/
/* out: TRUE if pointer to block */
void* ptr); /* in: pointer to memory */
+#ifdef UNIV_DEBUG
/*************************************************************************
Validates the buffer pool data structure. */
ibool
buf_validate(void);
/*==============*/
+#endif /* UNIV_DEBUG */
/************************************************************************
Prints a page to stderr. */
@@ -816,7 +820,7 @@ struct buf_pool_struct{
ulint n_pend_reads; /* number of pending read operations */
- time_t last_printout_time; /* when buf_print was last time
+ time_t last_printout_time; /* when buf_print_io was last time
called */
ulint n_pages_read; /* number read operations */
ulint n_pages_written;/* number write operations */
@@ -828,10 +832,10 @@ struct buf_pool_struct{
counted as page gets; this field
is NOT protected by the buffer
pool mutex */
- ulint n_page_gets_old;/* n_page_gets when buf_print was
+ ulint n_page_gets_old;/* n_page_gets when buf_print_io was
last time called: used to calculate
hit rate */
- ulint n_pages_read_old;/* n_pages_read when buf_print was
+ ulint n_pages_read_old;/* n_pages_read when buf_print_io was
last time called */
ulint n_pages_written_old;/* number write operations */
ulint n_pages_created_old;/* number of pages created in